/**
 * @file
 * VuoList_VuoColor C type definition.
 *
 * @copyright Copyright © 2012–2013 Kosada Incorporated.
 * This code may be modified and distributed under the terms of the MIT License.
 * For more information, see http://vuo.org/license.
 */

#ifndef VuoList_VuoColor_H
#define VuoList_VuoColor_H

/**
 * @ingroup VuoTypes
 * @defgroup VuoList_VuoColor VuoList_VuoColor
 * A list of @ref VuoColor elements.
 *
 * @{
 */

// This header is generated by vuo/type/list/generateVariants.sh.

/**
 * @typedef VuoList_VuoColor
 * A list of @ref VuoColor elements.
 */
#ifndef VuoList_VuoColor_TYPE_DEFINED
typedef void * VuoList_VuoColor;
#endif

/**
 * Creates a new list of @ref VuoColor elements.
 */
VuoList_VuoColor VuoListCreate_VuoColor(void);

/**
 * Returns the @ref VuoColor at @c index.
 * Index values start at 1.
 * If the list has no items, returns a default value.
 * Attempting to access an out-of-bounds index returns the first item in the list (if the index is 0), or last item in the list (if the index is greater than the list size).
 */
VuoColor VuoListGetValueAtIndex_VuoColor(const VuoList_VuoColor list, const unsigned long index);

/**
 * Appends @c value to @c list.
 */
void VuoListAppendValue_VuoColor(VuoList_VuoColor list, const VuoColor value);

/**
 * Removes the last value from @c list.
 */
void VuoListRemoveLastValue_VuoColor(VuoList_VuoColor list);

/**
 * Removes all values from @c list.
 */
void VuoListRemoveAll_VuoColor(VuoList_VuoColor list);

/**
 * Returns the number of elements in @c list.
 */
unsigned long VuoListGetCount_VuoColor(const VuoList_VuoColor list);

/**
 * Decodes the JSON object @c js to create a new value.
 *
 * @eg{
 *	["uno", "dos", "tres", "catorce"]
 * }
 */
VuoList_VuoColor VuoList_VuoColor_valueFromJson(struct json_object * js);

/**
 * Encodes @c value as a JSON object.
 */
struct json_object * VuoList_VuoColor_jsonFromValue(const VuoList_VuoColor value);

/**
 * Produces a brief human-readable summary of @c value.
 */
char * VuoList_VuoColor_summaryFromValue(const VuoList_VuoColor value);

/// @{
/**
 * Automatically generated function.
 */
VuoList_VuoColor VuoList_VuoColor_valueFromString(const char *str);
char * VuoList_VuoColor_stringFromValue(const VuoList_VuoColor value);
/// @}

/**
 * @}
 */

#endif
